Convert a seurat object to an anndata object using reticulate
Source:R/SCP-analysis.R
srt_to_adata.RdThis function takes a Seurat object and converts it to an anndata object using the reticulate package.
Usage
srt_to_adata(
srt,
features = NULL,
assay_X = "RNA",
slot_X = "counts",
assay_layers = c("spliced", "unspliced"),
slot_layers = "counts",
convert_tools = FALSE,
convert_misc = FALSE,
verbose = TRUE
)Arguments
- srt
A Seurat object.
- features
Optional vector of features to include in the anndata object. Defaults to all features in assay_X.
- assay_X
Assay to convert as the main data matrix (X) in the anndata object.
- slot_X
Slot name for assay_X in the Seurat object.
- assay_layers
Assays to convert as layers in the anndata object.
- slot_layers
Slot names for the assay_layers in the Seurat object.
- convert_tools
Logical indicating whether to convert the tool-specific data.
- convert_misc
Logical indicating whether to convert the miscellaneous data.
- verbose
Logical indicating whether to print verbose messages during the conversion process.
Examples
data("pancreas_sub")
adata <- srt_to_adata(pancreas_sub)
#> Error in check_Python(c("scanpy", "numpy")): could not find function "check_Python"
adata
#> Error: object 'adata' not found
### Or save as an h5ad file or a loom file
# adata$write_h5ad("pancreas_sub.h5ad")
# adata$write_loom("pancreas_sub.loom", write_obsm_varm = TRUE)